# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class PvtMode(Enum):
    """
    Mode of a PVT sequence.
    """

    DISABLED = 0
    STORE = 1
    LIVE = 2
